@@ -70,7 +70,7 @@ class TaurusTrend(PlotWidget, BaseConfigurableClass):
 
     def __init__(self, parent=None, **kwargs):
 
-        buffer_size = kwargs.pop('buffer_size', 65536)
+        buffer_size = kwargs.pop("buffer_size", 65536)
 
         if Qt.QT_VERSION < 0x050000:
             # Workaround for issue when using super with pyqt<5
@@ -100,11 +100,11 @@ class TaurusTrend(PlotWidget, BaseConfigurableClass):
 
         # add save & retrieve configuration actions
         saveConfigAction = QtGui.QAction("Save configuration", menu)
-        saveConfigAction.triggered.connect(self.saveConfigFile)
+        saveConfigAction.triggered.connect(self._onSaveConfigAction)
         menu.addAction(saveConfigAction)
 
         loadConfigAction = QtGui.QAction("Retrieve saved configuration", menu)
-        loadConfigAction.triggered.connect(self.loadConfigFile)
+        loadConfigAction.triggered.connect(self._onLoadConfigAction)
         menu.addAction(loadConfigAction)
 
         self.registerConfigProperty(self._getState, self.restoreState, "state")
@@ -190,6 +190,7 @@ class TaurusTrend(PlotWidget, BaseConfigurableClass):
         return ret
 
     def getTrendSets(self):
+        """Returns all the trend sets attached to this plot item"""
         return [
             e
             for e in self.getPlotItem().listDataItems()
@@ -197,6 +198,7 @@ class TaurusTrend(PlotWidget, BaseConfigurableClass):
         ]
 
     def clearTrends(self):
+        """Clear the buffers of all the trend sets in the plot"""
         for ts in self.getTrendSets():
             ts.clearBuffer()
 
@@ -238,6 +240,14 @@ class TaurusTrend(PlotWidget, BaseConfigurableClass):
         """Required generic TaurusTrend API """
         self.buffer_tool.setBufferSize(buffer_size)
 
+    def _onSaveConfigAction(self):
+        """wrapper to avoid issues with overloaded signals"""
+        return self.saveConfigFile()
+
+    def _onLoadConfigAction(self):
+        """wrapper to avoid issues with overloaded signals"""
+        return self.loadConfigFile()
+
 
 def trend_main(
     models=(), config_file=None, demo=False, window_name="TaurusTrend (pg)"
